Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(133)

Unified Diff: chromeos/dbus/power_manager_client.h

Issue 10916123: Add is_fullscreen to video updates (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chromeos/dbus/mock_power_manager_client.h ('k') | chromeos/dbus/power_manager_client.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/dbus/power_manager_client.h
diff --git a/chromeos/dbus/power_manager_client.h b/chromeos/dbus/power_manager_client.h
index e910232e17eca295ed72d33b784f19e67fa16f47..5be829891516534b97b41394800dcbce0520ccdc 100644
--- a/chromeos/dbus/power_manager_client.h
+++ b/chromeos/dbus/power_manager_client.h
@@ -156,9 +156,11 @@ class CHROMEOS_EXPORT PowerManagerClient {
virtual void NotifyUserActivity(
const base::TimeTicks& last_activity_time) = 0;
// Notifies the power manager that a video is currently playing.
virtual void NotifyVideoActivity(
- const base::TimeTicks& last_activity_time) = 0;
+ const base::TimeTicks& last_activity_time,
+ bool is_fullscreen) = 0;
// Override the current power state on the machine. The overrides will be
// applied to the request ID specified. To specify a new request; use 0 as
« no previous file with comments | « chromeos/dbus/mock_power_manager_client.h ('k') | chromeos/dbus/power_manager_client.cc » ('j') | no next file with comments »
@@ -156,9 +156,11 @@ class CHROMEOS_EXPORT PowerManagerClient {
virtual void NotifyUserActivity(
const base::TimeTicks& last_activity_time) = 0;
- // Notifies the power manager that a video is currently playing.
+ // Notifies the power manager that a video is currently playing. It also
+ // includes whether or not the containing window for the video is fullscreen.
virtual void NotifyVideoActivity(

Powered by Google App Engine
This is Rietveld 408576698